@@ -70,7 +70,7 @@ pub type RecycleResult<E> = Result<(), RecycleError<E>>;
 
 /// This trait is used to `create` new objects or `recycle` existing ones.
 #[async_trait]
-pub trait Manager {
+pub trait Manager: Sync + Send {
     /// Type that the manager creates and recycles.
     type Type;
     /// The error that the manager can return when creating and recycling
@@ -211,7 +211,7 @@ struct PoolInner<M: Manager> {
 /// and uses reference counting for its internal state.
 pub struct Pool<M: Manager, W: From<Object<M>> = Object<M>> {
     inner: Arc<PoolInner<M>>,
-    _wrapper: PhantomData<W>,
+    _wrapper: PhantomData<fn() -> W>,
 }
 
 impl<M: Manager, W: From<Object<M>>> Clone for Pool<M, W> {
